CredentialType class

Represents a credential

Constructors

CredentialType({required String type, required String id, required List<String?> transports})

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String
The ID of the credential.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transports ↔ List<String?>
The transports of the credential.
getter/setter pair
type ↔ String
The type of the credential.
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → CredentialType